---
layout: default
title: Joystick Control
parent: Examples
nav_order: 9
---

# Using a Joystick to Control ODrive
{: .no_toc }

1. TOC
{:toc}
---

For some applications of ODrive, we want to control a motor with a joystick.
Take a look at the 'examples' folder in the GitHub repo for how to connect a joystick to a ODrive motor.